summaryrefslogtreecommitdiffstats
path: root/test/tmisc.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2018-10-25 23:32:13 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2018-10-25 23:32:13 (GMT)
commit4a328957243ca7502a4c4966d6598498be43e3cd (patch)
treeb46c66d7532db54cdf010b577b9bdfcd9b2dbc8c /test/tmisc.c
parent0df6e44a6e68da1614cf80b50ed7b208edaa5df7 (diff)
parent47f30b474bdc498c20bd6d2a0ba7e8947ab389f0 (diff)
downloadhdf5-4a328957243ca7502a4c4966d6598498be43e3cd.zip
hdf5-4a328957243ca7502a4c4966d6598498be43e3cd.tar.gz
hdf5-4a328957243ca7502a4c4966d6598498be43e3cd.tar.bz2
Merge branch 'develop' of https://bitbucket.hdfgroup.org/scm/hdffv/hdf5 into stackable_vol
Diffstat (limited to 'test/tmisc.c')
-rw-r--r--test/tmisc.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/test/tmisc.c b/test/tmisc.c
index c7fb4a9..02521e4 100644
--- a/test/tmisc.c
+++ b/test/tmisc.c
@@ -3481,15 +3481,15 @@ test_misc19(void)
HDfree(vfd_cls);
-/* Check H5I operations on virtual object drivers */
+/* Check H5I operations on virtual object plugins */
/* Get a VOL class to register */
vol_cls = h5_get_dummy_vol_class();
CHECK(vol_cls, NULL, "h5_get_dummy_vol_class");
- /* Register a virtual object driver */
- volid = H5VLregister(vol_cls, H5P_DEFAULT);
- CHECK(volid, FAIL, "H5VLregister");
+ /* Register a VOL plugin */
+ volid = H5VLregister_plugin(vol_cls, H5P_DEFAULT);
+ CHECK(volid, FAIL, "H5VLregister_plugin");
/* Check the reference count */
rc = H5Iget_ref(volid);
@@ -3499,23 +3499,23 @@ test_misc19(void)
rc = H5Iinc_ref(volid);
VERIFY(rc, 2, "H5Iinc_ref");
- /* Unregister the VOL driver normally */
- ret = H5VLunregister(volid);
- CHECK(ret, FAIL, "H5VLunregister");
+ /* Unregister the VOL plugin normally */
+ ret = H5VLunregister_plugin(volid);
+ CHECK(ret, FAIL, "H5VLunregister_plugin");
/* Check the reference count */
rc = H5Iget_ref(volid);
VERIFY(rc, 1, "H5Iget_ref");
/* Unregister the VOL driver by decrementing the reference count */
rc = H5Idec_ref(volid);
VERIFY(rc, 0, "H5Idec_ref");
/* Try unregistering the VOL driver again (should fail) */
H5E_BEGIN_TRY {
- ret = H5VLunregister(volid);
+ ret = H5VLunregister_plugin(volid);
} H5E_END_TRY;
- VERIFY(ret, FAIL, "H5VLunregister");
+ VERIFY(ret, FAIL, "H5VLunregister_plugin");
HDfree(vol_cls);
@@ -3499,23 +3499,23 @@ test_misc19(void)
rc = H5Iget_ref(volid);
VERIFY(rc, 1, "H5Iget_ref");
- /* Unregister the VOL driver by decrementing the reference count */
+ /* Unregister the VOL plugin by decrementing the reference count */
rc = H5Idec_ref(volid);
VERIFY(rc, 0, "H5Idec_ref");
@@ -3499,23 +3499,23 @@ test_misc19(void)
rc = H5Idec_ref(volid);
VERIFY(rc, 0, "H5Idec_ref");
- /* Try unregistering the VOL driver again (should fail) */
+ /* Try unregistering the VOL plugin again (should fail) */
H5E_BEGIN_TRY {